@@ -132,59 +132,62 @@
 #'
 #' # you can remove a specific geom to reduce complexity of the plot
 #' ggbetweenstats(
-#'   mtcars, am, wt,
+#'   mtcars,
+#'   am,
+#'   wt,
 #'   # to remove violin plot
-#'   violin.args = list(width = 0),
+#'   violin.args = list(width = 0, linewidth = 0),
 #'   # to remove boxplot
 #'   boxplot.args = list(width = 0),
 #'   # to remove points
 #'   point.args = list(alpha = 0)
 #' )
 #' @export
-ggbetweenstats <- function(data,
-                           x,
-                           y,
-                           type = "parametric",
-                           pairwise.display = "significant",
-                           p.adjust.method = "holm",
-                           effsize.type = "unbiased",
-                           bf.prior = 0.707,
-                           bf.message = TRUE,
-                           results.subtitle = TRUE,
-                           xlab = NULL,
-                           ylab = NULL,
-                           caption = NULL,
-                           title = NULL,
-                           subtitle = NULL,
-                           k = 2L,
-                           var.equal = FALSE,
-                           conf.level = 0.95,
-                           nboot = 100L,
-                           tr = 0.2,
-                           centrality.plotting = TRUE,
-                           centrality.type = type,
-                           centrality.point.args = list(size = 5, color = "darkred"),
-                           centrality.label.args = list(
-                             size = 3,
-                             nudge_x = 0.4,
-                             segment.linetype = 4,
-                             min.segment.length = 0
-                           ),
-                           point.args = list(
-                             position = ggplot2::position_jitterdodge(dodge.width = 0.60),
-                             alpha = 0.4,
-                             size = 3,
-                             stroke = 0,
-                             na.rm = TRUE
-                           ),
-                           boxplot.args = list(width = 0.3, alpha = 0.2, na.rm = TRUE),
-                           violin.args = list(width = 0.5, alpha = 0.2, na.rm = TRUE),
-                           ggsignif.args = list(textsize = 3, tip_length = 0.01, na.rm = TRUE),
-                           ggtheme = ggstatsplot::theme_ggstatsplot(),
-                           package = "RColorBrewer",
-                           palette = "Dark2",
-                           ggplot.component = NULL,
-                           ...) {
+ggbetweenstats <- function(
+    data,
+    x,
+    y,
+    type = "parametric",
+    pairwise.display = "significant",
+    p.adjust.method = "holm",
+    effsize.type = "unbiased",
+    bf.prior = 0.707,
+    bf.message = TRUE,
+    results.subtitle = TRUE,
+    xlab = NULL,
+    ylab = NULL,
+    caption = NULL,
+    title = NULL,
+    subtitle = NULL,
+    k = 2L,
+    var.equal = FALSE,
+    conf.level = 0.95,
+    nboot = 100L,
+    tr = 0.2,
+    centrality.plotting = TRUE,
+    centrality.type = type,
+    centrality.point.args = list(size = 5, color = "darkred"),
+    centrality.label.args = list(
+      size = 3,
+      nudge_x = 0.4,
+      segment.linetype = 4,
+      min.segment.length = 0
+    ),
+    point.args = list(
+      position = ggplot2::position_jitterdodge(dodge.width = 0.60),
+      alpha = 0.4,
+      size = 3,
+      stroke = 0,
+      na.rm = TRUE
+    ),
+    boxplot.args = list(width = 0.3, alpha = 0.2, na.rm = TRUE),
+    violin.args = list(width = 0.5, alpha = 0.2, na.rm = TRUE),
+    ggsignif.args = list(textsize = 3, tip_length = 0.01, na.rm = TRUE),
+    ggtheme = ggstatsplot::theme_ggstatsplot(),
+    package = "RColorBrewer",
+    palette = "Dark2",
+    ggplot.component = NULL,
+    ...) {
   # data -----------------------------------
 
 
@@ -200,8 +203,7 @@ ggbetweenstats <- function(data,
 
   # statistical analysis ------------------------------------------
 
-  # test to run; depends on the no. of levels of the independent variable
-  test <- ifelse(nlevels(data %>% pull({{ x }})) < 3L, "t", "anova")
+  test <- ifelse(nlevels(pull(data, {{ x }})) < 3L, "t", "anova")
 
   if (results.subtitle) {
     .f.args <- list(
@@ -220,17 +222,17 @@ ggbetweenstats <- function(data,
 
     .f <- .f_switch(test)
     subtitle_df <- .eval_f(.f, !!!.f.args, type = type)
-    subtitle <- if (!is.null(subtitle_df)) subtitle_df$expression[[1L]]
+    subtitle <- .extract_expression(subtitle_df)
 
     if (type == "parametric" && bf.message) {
       caption_df <- .eval_f(.f, !!!.f.args, type = "bayes")
-      caption <- if (!is.null(caption_df)) caption_df$expression[[1L]]
+      caption <- .extract_expression(caption_df)
     }
   }
 
   # plot -----------------------------------
 
-  plot <- ggplot(data, mapping = aes({{ x }}, {{ y }})) +
+  plot_comparison <- ggplot(data, mapping = aes({{ x }}, {{ y }})) +
     exec(geom_point, aes(color = {{ x }}), !!!point.args) +
     exec(geom_boxplot, !!!boxplot.args, outlier.shape = NA) +
     exec(geom_violin, !!!violin.args)
@@ -238,8 +240,8 @@ ggbetweenstats <- function(data,
   # centrality tagging -------------------------------------
 
   if (isTRUE(centrality.plotting)) {
-    plot <- suppressWarnings(.centrality_ggrepel(
-      plot                  = plot,
+    plot_comparison <- suppressWarnings(.centrality_ggrepel(
+      plot                  = plot_comparison,
       data                  = data,
       x                     = {{ x }},
       y                     = {{ y }},
@@ -269,8 +271,8 @@ ggbetweenstats <- function(data,
     )
 
     # adding the layer for pairwise comparisons
-    plot <- .ggsignif_adder(
-      plot             = plot,
+    plot_comparison <- .ggsignif_adder(
+      plot             = plot_comparison,
       mpc_df           = mpc_df,
       data             = data,
       x                = {{ x }},
@@ -286,8 +288,8 @@ ggbetweenstats <- function(data,
   # annotations ------------------------
 
   .aesthetic_addon(
-    plot             = plot,
-    x                = data %>% pull({{ x }}),
+    plot             = plot_comparison,
+    x                = pull(data, {{ x }}),
     xlab             = xlab %||% as_name(x),
     ylab             = ylab %||% as_name(y),
     title            = title,
@@ -355,11 +357,12 @@ ggbetweenstats <- function(data,
 #'   )
 #' )
 #' @export
-grouped_ggbetweenstats <- function(data,
-                                   ...,
-                                   grouping.var,
-                                   plotgrid.args = list(),
-                                   annotation.args = list()) {
+grouped_ggbetweenstats <- function(
+    data,
+    ...,
+    grouping.var,
+    plotgrid.args = list(),
+    annotation.args = list()) {
   .grouped_list(data, {{ grouping.var }}) %>%
     purrr::pmap(.f = ggbetweenstats, ...) %>%
     combine_plots(plotgrid.args, annotation.args)
