@@ -116,34 +116,40 @@
 #' # further arguments can be passed to `parameters::model_parameters()`
 #' ggcoefstats(lmer(Reaction ~ Days + (Days | Subject), sleepstudy), effects = "fixed")
 #' @export
-ggcoefstats <- function(x,
-                        statistic = NULL,
-                        conf.int = TRUE,
-                        conf.level = 0.95,
-                        k = 2L,
-                        exclude.intercept = FALSE,
-                        effectsize.type = "eta",
-                        meta.analytic.effect = FALSE,
-                        meta.type = "parametric",
-                        bf.message = TRUE,
-                        sort = "none",
-                        xlab = NULL,
-                        ylab = NULL,
-                        title = NULL,
-                        subtitle = NULL,
-                        caption = NULL,
-                        only.significant = FALSE,
-                        point.args = list(size = 3.0, color = "blue", na.rm = TRUE),
-                        errorbar.args = list(height = 0, na.rm = TRUE),
-                        vline = TRUE,
-                        vline.args = list(linewidth = 1.0, linetype = "dashed"),
-                        stats.labels = TRUE,
-                        stats.label.color = NULL,
-                        stats.label.args = list(size = 3.0, direction = "y", min.segment.length = 0),
-                        package = "RColorBrewer",
-                        palette = "Dark2",
-                        ggtheme = ggstatsplot::theme_ggstatsplot(),
-                        ...) {
+ggcoefstats <- function(
+    x,
+    statistic = NULL,
+    conf.int = TRUE,
+    conf.level = 0.95,
+    k = 2L,
+    exclude.intercept = FALSE,
+    effectsize.type = "eta",
+    meta.analytic.effect = FALSE,
+    meta.type = "parametric",
+    bf.message = TRUE,
+    sort = "none",
+    xlab = NULL,
+    ylab = NULL,
+    title = NULL,
+    subtitle = NULL,
+    caption = NULL,
+    only.significant = FALSE,
+    point.args = list(size = 3.0, color = "blue", na.rm = TRUE),
+    errorbar.args = list(height = 0, na.rm = TRUE),
+    vline = TRUE,
+    vline.args = list(linewidth = 1.0, linetype = "dashed"),
+    stats.labels = TRUE,
+    stats.label.color = NULL,
+    stats.label.args = list(
+      size = 3.0,
+      direction = "y",
+      min.segment.length = 0,
+      na.rm = TRUE
+    ),
+    package = "RColorBrewer",
+    palette = "Dark2",
+    ggtheme = ggstatsplot::theme_ggstatsplot(),
+    ...) {
   # model check -------------------------
 
   # if a data frame is entered then `statistic` is necessary to create labels
@@ -164,8 +170,7 @@ ggcoefstats <- function(x,
       ci              = conf.level,
       table_wide      = TRUE,
       ...
-    ) %>%
-      rename_all(~ gsub("omega2.|eta2.", "", .x))
+    )
 
     # anova objects need further cleaning
     if (all(c("df", "df.error") %in% names(tidy_df))) tidy_df %<>% mutate(effectsize = paste0("partial ", effectsize.type, "-squared"))
@@ -178,7 +183,7 @@ ggcoefstats <- function(x,
   }
 
   # create a new term column if it's not present
-  if (!"term" %in% names(tidy_df)) tidy_df %<>% mutate(term = paste("term", row_number(), sep = "_"))
+  if (!"term" %in% names(tidy_df)) tidy_df %<>% mutate(term = paste0("term_", row_number()))
 
   # check for duplicate terms and columns -------------------------
 
@@ -225,7 +230,7 @@ ggcoefstats <- function(x,
 
   tidy_df %<>% parameters::sort_parameters(sort = sort, column = "estimate")
 
-  # `term` needs to be a factor column; otherwise, ggplot2 will sort the x-axis
+  # `term` needs to be a factor column; otherwise, ggplot2 will sort the `x`-axis
   # labels alphabetically and terms won't appear in the expected order
   tidy_df %<>% dplyr::mutate(term = factor(term, tidy_df$term))
 
@@ -235,7 +240,7 @@ ggcoefstats <- function(x,
 
   if (!is.null(glance_df) && all(c("AIC", "BIC") %in% names(glance_df))) {
     glance_df %<>% mutate(expression = list(parse(text = glue("list(AIC=='{format_value(AIC, 0L)}', BIC=='{format_value(BIC, 0L)}')"))))
-    caption <- glance_df$expression[[1L]]
+    caption <- .extract_expression(glance_df)
   }
 
   # meta analysis -------------------------
@@ -243,25 +248,25 @@ ggcoefstats <- function(x,
   if (meta.analytic.effect) {
     meta.type <- stats_type_switch(meta.type)
 
-    # results from frequentist random-effects meta-analysis
+    # frequentist
     subtitle_df <- meta_analysis(tidy_df, type = meta.type, k = k)
-    subtitle <- subtitle_df$expression[[1L]]
+    subtitle <- .extract_expression(subtitle_df)
 
-    # results from Bayesian random-effects meta-analysis (only for parametric)
+    # Bayesian
     if (meta.type == "parametric" && bf.message) {
       caption_df <- suppressWarnings(meta_analysis(tidy_df, type = "bayes", k = k))
-      caption <- caption_df$expression[[1L]]
+      caption <- .extract_expression(caption_df)
     }
   }
 
   # basic plot -------------------------
 
-  plot <- ggplot(tidy_df, mapping = aes(estimate, term)) +
+  plot_coef <- ggplot(tidy_df, mapping = aes(estimate, term)) +
     exec(geom_point, !!!point.args)
 
   # adding confidence intervals
   if (conf.int) {
-    plot <- plot +
+    plot_coef <- plot_coef +
       exec(
         geom_errorbarh,
         data    = tidy_df,
@@ -271,30 +276,29 @@ ggcoefstats <- function(x,
   }
 
   # adding the vertical line
-  if (vline) plot <- plot + exec(geom_vline, xintercept = 0, !!!vline.args)
+  if (vline) plot_coef <- plot_coef + exec(geom_vline, xintercept = 0, !!!vline.args)
 
   # ggrepel labels -------------------------
 
   if (stats.labels) {
-    if (is.null(stats.label.color) && .palette_message(package, palette, length(tidy_df$term))) {
+    if (is.null(stats.label.color) && .is_palette_sufficient(package, palette, length(tidy_df$term))) {
       stats.label.color <- paletteer::paletteer_d(paste0(package, "::", palette), length(tidy_df$term))
     }
 
-    plot <- plot +
+    plot_coef <- plot_coef +
       exec(
         ggrepel::geom_label_repel,
         data    = tidy_df,
         mapping = aes(x = estimate, y = term, label = expression),
         parse   = TRUE,
         color   = stats.label.color %||% "black",
-        na.rm   = TRUE,
         !!!stats.label.args
       )
   }
 
   # annotations -------------------------
 
-  plot +
+  plot_coef +
     labs(
       x        = xlab %||% "estimate",
       y        = ylab %||% "term",
