@@ -47,30 +47,31 @@
 #' # extracting details from statistical tests
 #' extract_stats(p)
 #' @export
-ggdotplotstats <- function(data,
-                           x,
-                           y,
-                           xlab = NULL,
-                           ylab = NULL,
-                           title = NULL,
-                           subtitle = NULL,
-                           caption = NULL,
-                           type = "parametric",
-                           test.value = 0,
-                           bf.prior = 0.707,
-                           bf.message = TRUE,
-                           effsize.type = "g",
-                           conf.level = 0.95,
-                           tr = 0.2,
-                           k = 2L,
-                           results.subtitle = TRUE,
-                           point.args = list(color = "black", size = 3, shape = 16),
-                           centrality.plotting = TRUE,
-                           centrality.type = type,
-                           centrality.line.args = list(color = "blue", linewidth = 1, linetype = "dashed"),
-                           ggplot.component = NULL,
-                           ggtheme = ggstatsplot::theme_ggstatsplot(),
-                           ...) {
+ggdotplotstats <- function(
+    data,
+    x,
+    y,
+    xlab = NULL,
+    ylab = NULL,
+    title = NULL,
+    subtitle = NULL,
+    caption = NULL,
+    type = "parametric",
+    test.value = 0,
+    bf.prior = 0.707,
+    bf.message = TRUE,
+    effsize.type = "g",
+    conf.level = 0.95,
+    tr = 0.2,
+    k = 2L,
+    results.subtitle = TRUE,
+    point.args = list(color = "black", size = 3, shape = 16),
+    centrality.plotting = TRUE,
+    centrality.type = type,
+    centrality.line.args = list(color = "blue", linewidth = 1, linetype = "dashed"),
+    ggplot.component = NULL,
+    ggtheme = ggstatsplot::theme_ggstatsplot(),
+    ...) {
   # data -----------------------------------
 
 
@@ -105,24 +106,22 @@ ggdotplotstats <- function(data,
       bf.prior     = bf.prior
     )
 
-    # subtitle with statistical results
     subtitle_df <- .eval_f(one_sample_test, !!!.f.args, type = type)
-    subtitle <- if (!is.null(subtitle_df)) subtitle_df$expression[[1L]]
+    subtitle <- .extract_expression(subtitle_df)
 
-    # BF message
     if (type == "parametric" && bf.message) {
       caption_df <- .eval_f(one_sample_test, !!!.f.args, type = "bayes")
-      caption <- if (!is.null(caption_df)) caption_df$expression[[1L]]
+      caption <- .extract_expression(caption_df)
     }
   }
 
   # plot -----------------------------------
 
-  plot <- ggplot(data, mapping = aes({{ x }}, y = rank)) +
+  plot_dot <- ggplot(data, mapping = aes({{ x }}, y = rank)) +
     exec(geom_point, !!!point.args) +
     scale_y_continuous(
       name = ylab,
-      labels = data %>% pull({{ y }}),
+      labels = pull(data, {{ y }}),
       breaks = data$rank,
       sec.axis = dup_axis(
         name   = "percentile",
@@ -134,9 +133,9 @@ ggdotplotstats <- function(data,
   # centrality plotting -------------------------------------
 
   if (isTRUE(centrality.plotting)) {
-    plot <- .histo_labeller(
-      plot,
-      x                    = data %>% pull({{ x }}),
+    plot_dot <- .histo_labeller(
+      plot_dot,
+      x                    = pull(data, {{ x }}),
       type                 = stats_type_switch(centrality.type),
       tr                   = tr,
       k                    = k,
@@ -146,7 +145,7 @@ ggdotplotstats <- function(data,
 
   # annotations -------------------------
 
-  plot +
+  plot_dot +
     labs(
       x        = xlab %||% as_name(x),
       y        = ylab %||% as_name(y),
@@ -197,11 +196,12 @@ ggdotplotstats <- function(data,
 #'   test.value   = 15.5
 #' )
 #' @export
-grouped_ggdotplotstats <- function(data,
-                                   ...,
-                                   grouping.var,
-                                   plotgrid.args = list(),
-                                   annotation.args = list()) {
+grouped_ggdotplotstats <- function(
+    data,
+    ...,
+    grouping.var,
+    plotgrid.args = list(),
+    annotation.args = list()) {
   .grouped_list(data, {{ grouping.var }}) %>%
     purrr::pmap(.f = ggdotplotstats, ...) %>%
     combine_plots(plotgrid.args, annotation.args)
