@@ -63,34 +63,35 @@
 #' ggpiestats(mtcars, vs, cyl)
 #'
 #' @export
-ggpiestats <- function(data,
-                       x,
-                       y = NULL,
-                       counts = NULL,
-                       type = "parametric",
-                       paired = FALSE,
-                       results.subtitle = TRUE,
-                       label = "percentage",
-                       label.args = list(direction = "both"),
-                       label.repel = FALSE,
-                       k = 2L,
-                       proportion.test = results.subtitle,
-                       perc.k = 0L,
-                       bf.message = TRUE,
-                       ratio = NULL,
-                       conf.level = 0.95,
-                       sampling.plan = "indepMulti",
-                       fixed.margin = "rows",
-                       prior.concentration = 1,
-                       title = NULL,
-                       subtitle = NULL,
-                       caption = NULL,
-                       legend.title = NULL,
-                       ggtheme = ggstatsplot::theme_ggstatsplot(),
-                       package = "RColorBrewer",
-                       palette = "Dark2",
-                       ggplot.component = NULL,
-                       ...) {
+ggpiestats <- function(
+    data,
+    x,
+    y = NULL,
+    counts = NULL,
+    type = "parametric",
+    paired = FALSE,
+    results.subtitle = TRUE,
+    label = "percentage",
+    label.args = list(direction = "both"),
+    label.repel = FALSE,
+    k = 2L,
+    proportion.test = results.subtitle,
+    perc.k = 0L,
+    bf.message = TRUE,
+    ratio = NULL,
+    conf.level = 0.95,
+    sampling.plan = "indepMulti",
+    fixed.margin = "rows",
+    prior.concentration = 1,
+    title = NULL,
+    subtitle = NULL,
+    caption = NULL,
+    legend.title = NULL,
+    ggtheme = ggstatsplot::theme_ggstatsplot(),
+    package = "RColorBrewer",
+    palette = "Dark2",
+    ggplot.component = NULL,
+    ...) {
   # data frame ------------------------------------------
 
   type <- stats_type_switch(type)
@@ -111,10 +112,10 @@ ggpiestats <- function(data,
 
   # x and y need to be a factor; also drop the unused levels of the factors
   data %<>% mutate(across(.cols = everything(), .fns = ~ droplevels(as.factor(.x))))
-  x_levels <- nlevels(data %>% pull({{ x }}))
-  y_levels <- ifelse(test == "one.way", 0L, nlevels(data %>% pull({{ y }})))
+  x_levels <- nlevels(pull(data, {{ x }}))
+  y_levels <- ifelse(test == "one.way", 0L, nlevels(pull(data, {{ y }})))
 
-  # TODO: one-way table in `BayesFactor`
+  # TODO: one-way table in `BayesFactor` (richarddmorey/BayesFactor#159)
   if (test == "two.way" && y_levels == 1L) bf.message <- FALSE
 
   # faceting is possible only if both vars have more than one level
@@ -138,12 +139,12 @@ ggpiestats <- function(data,
     )
 
     subtitle_df <- .eval_f(contingency_table, !!!.f.args, type = type)
-    if (!is.null(subtitle_df)) subtitle <- subtitle_df$expression[[1L]]
+    subtitle <- .extract_expression(subtitle_df)
 
     # Bayes Factor caption
     if (type != "bayes" && bf.message && isFALSE(paired)) {
       caption_df <- .eval_f(contingency_table, !!!.f.args, type = "bayes")
-      if (!is.null(caption_df)) caption <- caption_df$expression[[1L]]
+      caption <- .extract_expression(caption_df)
     }
   }
 
@@ -156,7 +157,7 @@ ggpiestats <- function(data,
   if (test == "two.way") onesample_df <- onesample_data(data, {{ x }}, {{ y }}, k)
 
   # if no. of factor levels is greater than the default palette color count
-  .palette_message(package, palette, min_length = x_levels)
+  .is_palette_sufficient(package, palette, min_length = x_levels)
 
   # creating the basic plot
   plotPie <- ggplot(descriptive_df, mapping = aes(x = "", y = perc)) +
@@ -249,11 +250,12 @@ ggpiestats <- function(data,
 #' # grouped one-sample proportion test
 #' grouped_ggpiestats(mtcars, x = cyl, grouping.var = am)
 #' @export
-grouped_ggpiestats <- function(data,
-                               ...,
-                               grouping.var,
-                               plotgrid.args = list(),
-                               annotation.args = list()) {
+grouped_ggpiestats <- function(
+    data,
+    ...,
+    grouping.var,
+    plotgrid.args = list(),
+    annotation.args = list()) {
   .grouped_list(data, {{ grouping.var }}) %>%
     purrr::pmap(.f = ggpiestats, ...) %>%
     combine_plots(plotgrid.args, annotation.args)
