@@ -77,34 +77,35 @@
 #' extract_stats(p)
 #'
 #' @export
-ggscatterstats <- function(data,
-                           x,
-                           y,
-                           type = "parametric",
-                           conf.level = 0.95,
-                           bf.prior = 0.707,
-                           bf.message = TRUE,
-                           tr = 0.2,
-                           k = 2L,
-                           results.subtitle = TRUE,
-                           label.var = NULL,
-                           label.expression = NULL,
-                           marginal = TRUE,
-                           point.args = list(size = 3, alpha = 0.4, stroke = 0),
-                           point.width.jitter = 0,
-                           point.height.jitter = 0,
-                           point.label.args = list(size = 3, max.overlaps = 1e6),
-                           smooth.line.args = list(linewidth = 1.5, color = "blue", method = "lm", formula = y ~ x),
-                           xsidehistogram.args = list(fill = "#009E73", color = "black", na.rm = TRUE),
-                           ysidehistogram.args = list(fill = "#D55E00", color = "black", na.rm = TRUE),
-                           xlab = NULL,
-                           ylab = NULL,
-                           title = NULL,
-                           subtitle = NULL,
-                           caption = NULL,
-                           ggtheme = ggstatsplot::theme_ggstatsplot(),
-                           ggplot.component = NULL,
-                           ...) {
+ggscatterstats <- function(
+    data,
+    x,
+    y,
+    type = "parametric",
+    conf.level = 0.95,
+    bf.prior = 0.707,
+    bf.message = TRUE,
+    tr = 0.2,
+    k = 2L,
+    results.subtitle = TRUE,
+    label.var = NULL,
+    label.expression = NULL,
+    marginal = TRUE,
+    point.args = list(size = 3, alpha = 0.4, stroke = 0),
+    point.width.jitter = 0,
+    point.height.jitter = 0,
+    point.label.args = list(size = 3, max.overlaps = 1e6),
+    smooth.line.args = list(linewidth = 1.5, color = "blue", method = "lm", formula = y ~ x),
+    xsidehistogram.args = list(fill = "#009E73", color = "black", na.rm = TRUE),
+    ysidehistogram.args = list(fill = "#D55E00", color = "black", na.rm = TRUE),
+    xlab = NULL,
+    ylab = NULL,
+    title = NULL,
+    subtitle = NULL,
+    caption = NULL,
+    ggtheme = ggstatsplot::theme_ggstatsplot(),
+    ggplot.component = NULL,
+    ...) {
   # data ---------------------------------------
 
   # ensure the arguments work quoted or unquoted
@@ -130,12 +131,12 @@ ggscatterstats <- function(data,
     )
 
     subtitle_df <- .eval_f(corr_test, !!!.f.args, type = type)
-    subtitle <- if (!is.null(subtitle_df)) subtitle_df$expression[[1L]]
+    subtitle <- .extract_expression(subtitle_df)
 
     # BF message for null hypothesis support
     if (type == "parametric" && bf.message) {
       caption_df <- .eval_f(corr_test, !!!.f.args, type = "bayes")
-      caption <- if (!is.null(caption_df)) caption_df$expression[[1L]]
+      caption <- .extract_expression(caption_df)
     }
   }
 
@@ -258,11 +259,12 @@ ggscatterstats <- function(data,
 #'   annotation.args = list(tag_levels = "a")
 #' )
 #' @export
-grouped_ggscatterstats <- function(data,
-                                   ...,
-                                   grouping.var,
-                                   plotgrid.args = list(),
-                                   annotation.args = list()) {
+grouped_ggscatterstats <- function(
+    data,
+    ...,
+    grouping.var,
+    plotgrid.args = list(),
+    annotation.args = list()) {
   .grouped_list(data, {{ grouping.var }}) %>%
     purrr::pmap(.f = ggscatterstats, ...) %>%
     combine_plots(plotgrid.args, annotation.args)
