@@ -1,4 +1,3 @@
-# creating a new dataset
 morley_new <- dplyr::mutate(
   morley,
   Expt = dplyr::case_when(
@@ -18,8 +17,8 @@ morley_new[87L, 3L] <- NA_integer_
 # checking default outputs -----------------------------------------
 
 test_that(
-  desc = "checking default outputs",
-  code = {
+  "checking default outputs",
+  {
     set.seed(123)
     expect_doppelganger(
       title = "parametric - without NA",
@@ -38,8 +37,8 @@ test_that(
 # modification with ggplot2 ----------------------------------------------
 
 test_that(
-  desc = "modification with ggplot2 works as expected",
-  code = {
+  "modification with ggplot2 works as expected",
+  {
     set.seed(123)
     expect_doppelganger(
       title = "modification with ggplot2 ",
@@ -63,27 +62,29 @@ test_that(
 # subtitle output -------------------------------------------------------
 
 test_that(
-  desc = "subtitle output",
-  code = {
+  "subtitle output",
+  {
     set.seed(123)
-    p_sub_ggdot <- suppressWarnings(ggdotplotstats(
+    p_sub_ggdot <- ggdotplotstats(
       data = morley,
       x = Speed,
       y = Expt,
       test.value = 800,
       type = "np"
     ) %>%
-      extract_subtitle())
+      extract_subtitle()
 
     set.seed(123)
-    p_sub_gghist <- suppressWarnings(gghistostats(
-      data = dplyr::group_by(morley, Expt) %>%
-        dplyr::summarise(mean = mean(Speed)),
-      x = mean,
-      test.value = 800,
-      type = "np"
-    ) %>%
-      extract_subtitle())
+    p_sub_gghist <-
+      morley %>%
+      dplyr::group_by(Expt) %>%
+      dplyr::summarise(mean = mean(Speed), .groups = "drop") %>%
+      gghistostats(
+        x = mean,
+        test.value = 800,
+        type = "np"
+      ) %>%
+      extract_subtitle()
 
     set.seed(123)
     expect_identical(p_sub_ggdot, p_sub_gghist)
@@ -93,8 +94,8 @@ test_that(
 # grouped_ggdotplotstats works -----------------------------------------------
 
 test_that(
-  desc = "grouped_ggdotplotstats works",
-  code = {
+  "grouped_ggdotplotstats works",
+  {
     # removing factor level with very few no. of observations
     df <- dplyr::filter(ggplot2::mpg, cyl %in% c("4", "6", "8"))
 
